@@ -1,3 +1,9 @@
+#undef PACKAGE
+#undef VERSION
+
+/* Define if you have a long long type */
+#undef HAVE_LONG_LONG
+
 /* Define if you have a working dlopen() */
 #undef HAVE_DLOPEN
 
@@ -17,6 +23,7 @@
 #undef HAVE_GETPT
 
 /* Define possible pty types */
+#undef PTYS_ARE_OPENPTY
 #undef PTYS_ARE_NUMERIC
 #undef PTYS_ARE_PTMX
 #undef PTYS_ARE_PTC
